@@ -14,7 +14,13 @@ from typing import Any
 import more_itertools
 
 from ._locker import Locker
-from .utils import SerializerMapping, find_files, instance_from_map, non_empty_file
+from .utils import (
+    SerializerMapping,
+    find_files,
+    init_serializer,
+    instance_from_map,
+    non_empty_file,
+)
 
 
 @dataclass
@@ -26,7 +32,7 @@ class ConfigResult:
 
 class Sampler(ABC):
     # pylint: disable=no-self-use,unused-argument
-    def __init__(self, budget: int | float | None):
+    def __init__(self, budget: int | float | None = None):
         self.used_budget: int | float = 0
         self.budget = budget
 
@@ -73,6 +79,15 @@ class Sampler(ABC):
         return config
 
 
+class Configuration:
+    """If the configuration is not a simple dictionary, it should inherit from
+    this object and define the 'hp_values' method"""
+
+    def hp_values(self):
+        """Should return a dictionary of the hyperparameter values"""
+        raise NotImplementedError
+
+
 def _load_sampled_paths(optimization_dir: Path | str, serializer, logger):
     optimization_dir = Path(optimization_dir)
     base_result_directory = optimization_dir / "results"
@@ -115,6 +130,16 @@ def _load_sampled_paths(optimization_dir: Path | str, serializer, logger):
     return previous_paths, pending_paths
 
 
+def read_config_result(result_dir: Path | str, serializer: str | Any = None, logger=None):
+    result_dir = Path(result_dir)
+    serializer = init_serializer(serializer, result_dir, logger)
+
+    config = serializer.load_config(result_dir / "config")
+    result = serializer.load(result_dir / "result")
+    metadata = serializer.load(result_dir / "metadata")
+    return ConfigResult(config, result, metadata)
+
+
 def read(
     optimization_dir: Path | str, serializer: str | Any = None, logger=None, do_lock=True
 ):
@@ -131,20 +156,7 @@ def read(
             time.sleep(2)
 
     # Try to guess the serialization method used
-    if serializer is None:
-        for name, serializer_cls in SerializerMapping.items():
-            data_files = [
-                f".optimizer_state{serializer_cls.SUFFIX}",
-                f"config{serializer_cls.SUFFIX}",
-                f"result{serializer_cls.SUFFIX}",
-            ]
-            if find_files(optimization_dir, data_files):
-                serializer = name
-                logger.debug(f"Auto-detected {name} format for serializer")
-                break
-        else:
-            serializer = "json"
-            logger.debug(f"Will use the {serializer} serializer as a default")
+    serializer = init_serializer(serializer, optimization_dir, logger)
 
     serializer = instance_from_map(SerializerMapping, serializer, "serializer")
     previous_paths, pending_paths = _load_sampled_paths(
@@ -152,11 +164,8 @@ def read(
     )
     previous_results, pending_configs, pending_configs_free = {}, {}, {}
 
-    for config_id, (config_dir, config_file, result_file) in previous_paths.items():
-        config = serializer.load_config(config_file)
-        result = serializer.load(result_file)
-        metadata = serializer.load(result_file.parent / "metadata")
-        previous_results[config_id] = ConfigResult(config, result, metadata)
+    for config_id, (config_dir, _, _) in previous_paths.items():
+        previous_results[config_id] = read_config_result(config_dir, serializer, logger)
 
     for config_id, (config_dir, config_file) in pending_paths.items():
         pending_configs[config_id] = serializer.load_config(config_file)
@@ -267,6 +276,8 @@ def _evaluate_config(
     previous_working_directory,
     logger,
 ):
+    if isinstance(config, Configuration):
+        config = config.hp_values()
     config = deepcopy(config)
     logger.info(f"Start evaluating config {config_id}")
     try:
@@ -424,14 +435,19 @@ def run(
                         # Updating the global budget
                         if "cost" in result:
                             eval_cost = float(result["cost"])
-                            with decision_locker.acquire_force(time_step=1):
-                                with sampler.using_state(sampler_state_file, serializer):
-                                    sampler.used_budget += eval_cost
+                            account_for_cost = result.get("account_for_cost", True)
+                            if account_for_cost:
+                                with decision_locker.acquire_force(time_step=1):
+                                    with sampler.using_state(
+                                        sampler_state_file, serializer
+                                    ):
+                                        sampler.used_budget += eval_cost
 
                             metadata["budget"] = {
                                 "max": sampler.budget,
                                 "used": sampler.used_budget,
                                 "eval_cost": eval_cost,
+                                "account_for_cost": account_for_cost,
                             }
                         elif sampler.budget is not None:
                             raise ValueError(
